@@ -4,12 +4,13 @@ namespace PhpParser\Node\Expr;
 
 use PhpParser\Node\Expr;
 
-/**
- * @property string $var   Name of variable
- * @property bool   $byRef Whether to use by reference
- */
 class ClosureUse extends Expr
 {
+    /** @var string Name of variable */
+    public $var;
+    /** @var bool Whether to use by reference */
+    public $byRef;
+
     /**
      * Constructs a closure use node.
      *
@@ -18,12 +19,12 @@ class ClosureUse extends Expr
      * @param array       $attributes Additional attributes
      */
     public function __construct($var, $byRef = false, array $attributes = array()) {
-        parent::__construct(
-            array(
-                'var'   => $var,
-                'byRef' => $byRef
-            ),
-            $attributes
-        );
+        parent::__construct(null, $attributes);
+        $this->var = $var;
+        $this->byRef = $byRef;
     }
-}
\ No newline at end of file
+
+    public function getSubNodeNames() {
+        return array('var', 'byRef');
+    }
+}
