@@ -30,7 +30,7 @@ class ClassTest extends \PHPUnit_Framework_TestCase
             'stmts' => array(
                 new TraitUse(array()),
                 $methods[0],
-                new Const_(array()),
+                new ClassConst(array()),
                 $methods[1],
                 new Property(0, array()),
                 $methods[2],
@@ -39,4 +39,21 @@ class ClassTest extends \PHPUnit_Framework_TestCase
 
         $this->assertSame($methods, $class->getMethods());
     }
-}
\ No newline at end of file
+
+    public function testGetMethod() {
+        $methodConstruct = new ClassMethod('__CONSTRUCT');
+        $methodTest = new ClassMethod('test');
+        $class = new Class_('Foo', array(
+            'stmts' => array(
+                new ClassConst(array()),
+                $methodConstruct,
+                new Property(0, array()),
+                $methodTest,
+            )
+        ));
+
+        $this->assertSame($methodConstruct, $class->getMethod('__construct'));
+        $this->assertSame($methodTest, $class->getMethod('test'));
+        $this->assertNull($class->getMethod('nonExisting'));
+    }
+}
